Subject: Re: bug#48792: CRAN/bioconductor updater downloads tarballs twice

From: zimoun <[email-masked]>
Date: Fri, 04 Nov 2022 13:27:39 +0100

Hi,

On mer., 02 juin 2021 at 17:54, Ricardo Wurmus <[email-masked]> wrote:
> When upgrading packages with “guix refresh -t bioconductor -u” Guix downloads
> tarballs for every package twice.

It can be worse with 3 downloads.

--8<---------------cut here---------------start------------->8---
$ ./pre-inst-env guix refresh -u r-rhdf5lib

Starting download of /tmp/guix-file.IjNx2z
>From https://bioconductor.org/packages/release/bioc/src/contrib/Rhdf5lib_1.20.0.tar.gz...
 …20.0.tar.gz  14.0MiB               96.9MiB/s 00:00 [##################] 100.0%
gnu/packages/bioconductor.scm:14362:13: r-rhdf5lib: updating from version 1.18.2 to version 1.20.0...

Starting download of /tmp/guix-file.NmqLjM
>From https://bioconductor.org/packages/release/bioc/src/contrib/Rhdf5lib_1.20.0.tar.gz...
 …20.0.tar.gz  14.0MiB               97.3MiB/s 00:00 [##################] 100.0%

Starting download of /tmp/guix-file.ytAuK3
>From https://bioconductor.org/packages/release/bioc/src/contrib/Rhdf5lib_1.20.0.tar.gz...
 …20.0.tar.gz  14.0MiB              103.3MiB/s 00:00 [##################] 100.0%
guix refresh: r-rhdf5lib: consider adding this input: zlib
gnu/packages/bioconductor.scm:14431:5: r-rhdf5lib: consider removing this native input: hdf5-source
gnu/packages/bioconductor.scm:14429:5: r-rhdf5lib: consider removing this propagated input: hdf5
gnu/packages/bioconductor.scm:14429:5: r-rhdf5lib: consider removing this propagated input: zlib
--8<---------------cut here---------------end--------------->8---

Cheers,
simon

PS: Noted when upgrading from 3.15 to 3.16 with this change.

--8<---------------cut here---------------start------------->8---
diff --git a/guix/build-system/r.scm b/guix/build-system/r.scm
index 620822b870..9b360ae581 100644
--- a/guix/build-system/r.scm
+++ b/guix/build-system/r.scm
@@ -61,7 +61,7 @@ (define* (bioconductor-uri name version #:optional type)
                          "/src/contrib/"
                          name "_" version ".tar.gz")
           ;; TODO: use %bioconductor-version from (guix import cran)
-          (string-append "https://bioconductor.org/packages/3.15"
+          (string-append "https://bioconductor.org/packages/3.16"
                          type-url-part
                          "/src/contrib/"
                          name "_" version ".tar.gz"))))
diff --git a/guix/import/cran.scm b/guix/import/cran.scm
index 4e1ce7c010..cdc6b806b2 100644
--- a/guix/import/cran.scm
+++ b/guix/import/cran.scm
@@ -156,9 +156,9 @@ (define %cran-url "https://cran.r-project.org/web/packages/")
 (define %cran-canonical-url "https://cran.r-project.org/package=")
 (define %bioconductor-url "https://bioconductor.org/packages/")

 ;; The latest Bioconductor release is 3.15.  Bioconductor packages should be
 ;; updated together.
-(define %bioconductor-version "3.15")
+(define %bioconductor-version "3.16")

 (define* (bioconductor-packages-list-url #:optional type)
   (string-append "https://bioconductor.org/packages/"
--8<---------------cut here---------------end--------------->8---
@@ -156,9 +156,9 @@ (define %cran-url "https://cran.r-project.org/web/packages/")
 (define %bioconductor-url "https://bioconductor.org/packages/")

-;; The latest Bioconductor release is 3.15.  Bioconductor packages should be
+;; The latest Bioconductor release is 3.16.  Bioconductor packages should be
 ;; updated together.